==> lifetype-1.1.tbz: www/lifetype/plugins/sociable/class/action/pluginsociableupdateconfigaction.class.php <==
<?php

    /*
    Copyright 2006 Paul Westbrook (paul@westbrooks.org)
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    */

	include_once( PLOG_CLASS_PATH."class/action/admin/adminaction.class.php" );
	include_once( PLOG_CLASS_PATH."plugins/sociable/class/view/pluginsociableconfigview.class.php" );
		
	/**
	 * updates the plugin configuration
	 */
	class PluginSociableUpdateConfigAction extends AdminAction
	{
		var $_pluginEnabled;
		var $_sitesArray;
		
		function PluginSociableUpdateConfigAction( $actionInfo, $request )
		{
			$this->AdminAction( $actionInfo, $request );
		}
		
		function validate()
		{
            global $sociable_builtin_known_sites;
            global $sociable_plugin_extra_sites;


        	include( PLOG_CLASS_PATH."plugins/sociable/class/sociable/sociable.php" );
        	include( PLOG_CLASS_PATH."plugins/sociable/class/extra/pluginsociableextrasites.inc.php" );



            $this->_pluginEnabled = $this->_request->getValue( "pluginEnabled" );
            $this->_pluginEnabled = ($this->_pluginEnabled != "" );			
			
			$this->_sitesArray = Array();
			
		    foreach($sociable_builtin_known_sites as $sitename=>$site)
		    {
		          $siteEnabled = $this->_request->getValue( strtr($sitename, ".", "_") );
		          $this->_sitesArray[$sitename] = ($siteEnabled != "" );
            }
		    foreach($sociable_plugin_extra_sites as $sitename=>$site)
		    {
		          $siteEnabled = $this->_request->getValue( strtr($sitename, ".", "_") );
		          $this->_sitesArray[$sitename] = ($siteEnabled != "" );
            }
			return true;
		}
		        
		function perform()
		{
            global $sociable_builtin_known_sites;
            global $sociable_plugin_extra_sites;

        	include( PLOG_CLASS_PATH."plugins/sociable/class/sociable/sociable.php" );
        	include( PLOG_CLASS_PATH."plugins/sociable/class/extra/pluginsociableextrasites.inc.php" );


            // update the plugin configurations to blog setting
			$blogSettings = $this->_blogInfo->getSettings();
            $blogSettings->setValue( "plugin_sociable_enabled", $this->_pluginEnabled );
            $this->_blogInfo->setSettings( $blogSettings ); 
		
   		    foreach($sociable_builtin_known_sites as $sitename=>$site)
		    {
                  $blogSettings->setValue( "plugin_sociable_" . $sitename . "_enabled", $this->_sitesArray[$sitename] );
            }
   		    foreach($sociable_plugin_extra_sites as $sitename=>$site)
		    {
                  $blogSettings->setValue( "plugin_sociable_" . $sitename . "_enabled", $this->_sitesArray[$sitename] );
            }

			// save the blogs settings
			$blogs = new Blogs();
            if( !$blogs->updateBlog( $this->_blogInfo )) {
                $this->_view = new PluginSociableConfigView( $this->_blogInfo );
                $this->_view->setErrorMessage( $this->_locale->tr("error_updating_settings"));
                $this->setCommonData();

                return false;                       
            }
			
			// if everything went ok...
            $this->_blogInfo->setSettings( $blogSettings );
            $this->_session->setValue( "blogInfo", $this->_blogInfo );
            $this->saveSession();
			
			$this->_view = new PluginSociableConfigView( $this->_blogInfo );
			$this->_view->setSuccessMessage( $this->_locale->tr("sociable_settings_saved_ok"));			
			$this->setCommonData();
			
			// clear the cache
			CacheControl::resetBlogCache( $this->_blogInfo->getId());					
            
            return true;		
		}
	}
?>

==> lifetype-1.2.11.tbz: www/lifetype/plugins/sociable/class/action/pluginsociableupdateconfigaction.class.php <==
<?php

    /*
    Copyright 2006 Paul Westbrook (paul@westbrooks.org)
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    */

	lt_include( PLOG_CLASS_PATH."class/action/admin/adminaction.class.php" );
	lt_include( PLOG_CLASS_PATH."plugins/sociable/class/view/pluginsociableconfigview.class.php" );
		
	/**
	 * updates the plugin configuration
	 */
	class PluginSociableUpdateConfigAction extends AdminAction
	{
		var $_pluginEnabled;
		var $_sitesArray;
		
		function PluginSociableUpdateConfigAction( $actionInfo, $request )
		{
			$this->AdminAction( $actionInfo, $request );
		}
		
		function validate()
		{
            global $sociable_builtin_known_sites;
            global $sociable_plugin_extra_sites;


        	include( PLOG_CLASS_PATH."plugins/sociable/class/sociable/sociable.php" );
        	include( PLOG_CLASS_PATH."plugins/sociable/class/extra/pluginsociableextrasites.inc.php" );



            $this->_pluginEnabled = $this->_request->getValue( "pluginEnabled" );
            $this->_pluginEnabled = ($this->_pluginEnabled != "" );			
			
			$this->_sitesArray = Array();
			
		    foreach($sociable_builtin_known_sites as $sitename=>$site)
		    {
		          $siteEnabled = $this->_request->getValue( strtr($sitename, ".", "_") );
		          $this->_sitesArray[$sitename] = ($siteEnabled != "" );
            }
		    foreach($sociable_plugin_extra_sites as $sitename=>$site)
		    {
		          $siteEnabled = $this->_request->getValue( strtr($sitename, ".", "_") );
		          $this->_sitesArray[$sitename] = ($siteEnabled != "" );
            }
			return true;
		}
		        
		function perform()
		{
            global $sociable_builtin_known_sites;
            global $sociable_plugin_extra_sites;

        	include( PLOG_CLASS_PATH."plugins/sociable/class/sociable/sociable.php" );
        	include( PLOG_CLASS_PATH."plugins/sociable/class/extra/pluginsociableextrasites.inc.php" );


            // update the plugin configurations to blog setting
			$blogSettings = $this->_blogInfo->getSettings();
            $blogSettings->setValue( "plugin_sociable_enabled", $this->_pluginEnabled );
            $this->_blogInfo->setSettings( $blogSettings ); 
		
   		    foreach($sociable_builtin_known_sites as $sitename=>$site)
		    {
                  $blogSettings->setValue( "plugin_sociable_" . $sitename . "_enabled", $this->_sitesArray[$sitename] );
            }
   		    foreach($sociable_plugin_extra_sites as $sitename=>$site)
		    {
                  $blogSettings->setValue( "plugin_sociable_" . $sitename . "_enabled", $this->_sitesArray[$sitename] );
            }

			// save the blogs settings
			$blogs = new Blogs();
            if( !$blogs->updateBlog( $this->_blogInfo )) {
                $this->_view = new PluginSociableConfigView( $this->_blogInfo );
                $this->_view->setErrorMessage( $this->_locale->tr("error_updating_settings"));
                $this->setCommonData();

                return false;                       
            }
			
			// if everything went ok...
            $this->_blogInfo->setSettings( $blogSettings );
            $this->_session->setValue( "blogInfo", $this->_blogInfo );
            $this->saveSession();
			
			$this->_view = new PluginSociableConfigView( $this->_blogInfo );
			$this->_view->setSuccessMessage( $this->_locale->tr("sociable_settings_saved_ok"));			
			$this->setCommonData();
			
			// clear the cache
			CacheControl::resetBlogCache( $this->_blogInfo->getId());					
            
            return true;		
		}
	}
?>
